package cordon.bleu.tour;


import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.*;
import javax.validation.constraints.*;
import java.util.Date;

@Entity
@Getter
@Setter
@Table(name="tour")
public class Tour {

	public enum Continent {
		AFRICA("Africa"), ASIA("Asia"), EUROPE("Europe"), NORTH_AMERICA("North America"), SOUTH_AMERICA("South America");

		private final String displayName;

		Continent(String displayName) {
			this.displayName = displayName;
		}

		public String getDisplayName() {
			return displayName;
		}
	}

	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	private int id;

	@OneToOne(mappedBy = "tour", optional=false, fetch = FetchType.LAZY)
	private TourInfo tourInfo;


	@Size(min = 5, message = "{tour.name}")
	private String name;

	@Pattern(regexp  = "^[a-zA-Z]{2}-[0-9]{2}[a-zA-Z]{1}$", message = "{tour.code}")
	private String code;

	@NotNull(message = "value mismatch")
	private Continent continent = Continent.EUROPE;

	@NotNull(message = "{tour.date.notnull}")
	@Future(message = "{tour.date.future}")
	@DateTimeFormat(pattern = "yyyy-MM-dd")
	private Date date;

	@Min(value = 7, message= "{tour.duration}" )
	@Max(value = 21, message= "{tour.duration}" )
	private int duration;

	@Column(name = "all_inclusive")
	private boolean allInclusive = false;


}
