package cordon.bleu.tour;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.server.ResponseStatusException;

import javax.validation.Valid;


@Controller
@RequestMapping("/tour")
public class TourController {

    private TourService tourService;

    @Autowired
    public void setTourService(TourService tourService) {
        this.tourService = tourService;
    }

    @GetMapping
    public String list(Model model) {
        model.addAttribute("tours", tourService.getAll());
        return "tour/list";
    }

    @GetMapping("/namecontains/{needle}")
    public String nameContains(@PathVariable String needle, Model model) {
        model.addAttribute("tours", tourService.getNameContains(needle));
        return "tour/list";
    }

    @GetMapping("/add")
    public String add(Model model) {
        model.addAttribute("tour", new Tour());
        return "tour/edit";
    }

    @PostMapping("/edit")
    public String processForm(@Valid @ModelAttribute Tour tour, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return "tour/edit";
        }
        tourService.saveOrUpdate(tour);
        return "redirect:/tour";
    }

    @GetMapping("/edit/{id}")
    public String edit(@PathVariable int id, Model model) {
        Tour tour = tourService.getById(id);
        if (tour == null) {
            throw new ResponseStatusException(HttpStatus.NOT_FOUND, "Resource not found on server");
        }
        model.addAttribute("tour", tour);
        return "tour/edit";
    }

    @GetMapping("/delete/{id}")
    public String delete(@PathVariable int id){
        Tour tour = tourService.getById(id);
        if (tour == null) {
            throw new ResponseStatusException(HttpStatus.NOT_FOUND, "Resource not found on server");
        }
        tourService.delete(tour);
        return "redirect:/tour";

    }



}
