package cordon.bleu.user;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.server.ResponseStatusException;

import javax.validation.Valid;

import static org.springframework.http.HttpStatus.NOT_FOUND;


@Controller
@RequestMapping("/user")
public class UserController {

    private UserService userService;

    @Autowired
    public void setUserService(UserService userService) {
        this.userService = userService;
    }

    @GetMapping
    public String list(Model model) {
        model.addAttribute("users", userService.getAll());
        return "user/list";
    }

    @GetMapping("/add")
    public String add(Model model) {
        User user = new User();
        user.setUserRole(new UserRole());
        model.addAttribute("user", user);
        return "user/edit";
    }

    @GetMapping("/edit/{id}")
    public String edit(@PathVariable int id, Model model) {
        User user = userService.getById(id);
        if (user == null) {
            throw new ResponseStatusException(NOT_FOUND, "Unable to find resource");
        }
        model.addAttribute("user", user);
        return "user/edit";
    }


    @PostMapping("/edit")
    public String processForm(@Valid @ModelAttribute User user, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return "user/edit";
        }
        user.getUserRole().setUser(user);
        userService.saveOrUpdate(user);
        return "redirect:/user";
    }

    @GetMapping("/delete/{id}")
    public String delete(@PathVariable int id) {
        User user = userService.getById(id);
        if (user == null) {
            throw new ResponseStatusException(NOT_FOUND, "Unable to find resource");
        }
        userService.delete(id);
        return "redirect:/user";
    }





}
